@@ -58,8 +58,8 @@ class TorchTagger:
         return FloatTensor(embedding.model.wv.vectors), word2index
 
 
-    @staticmethod
-    def evaluate_model(model, iterator):
+    #@staticmethod
+    def evaluate_model(self, model, iterator):
         """
         Evaluates the model using evaluation set & Tagging Report.
         :param: iterator: Instance of TorchText BucketIterator.
@@ -89,10 +89,10 @@ class TorchTagger:
         all_probs = np.clip(all_probs, 1e-5, 1-1e-5)
 
         all_y = np.array(all_y)
+        classes = list(self.label_index.keys())
 
         # report
-        report = TaggingReport(all_y, all_preds)
-
+        report = TaggingReport(all_y, all_preds, all_probs, classes)
         report.val_loss = -np.sum(all_y*np.log(all_probs) + (1-all_y)*np.log(1-all_probs))/len(all_y)
         return report
 
